@@ -1,6 +1,6 @@
 /* tutoterm.h -- header file for app functions
  *
- * Copyright © 2017,2019 Félicien Pillot <felicien@gnu.org>
+ * Copyright © 2017,2019-2020 Félicien Pillot <felicien@gnu.org>
  * This file is part of TutoTerm.
  * 
  * TutoTerm is free software: you can redistribute it and/or modify
@@ -22,21 +22,16 @@
 
 #include <gtk/gtk.h>
 
-void	   activate               (GtkApplication*    app,
-				   gpointer	      user_data);
-GtkWidget* get_ttlabel            (GtkWidget*         widget);
-GtkWidget* get_ttvtextbox         (GtkWidget*         widget);
-gboolean   key_event              (GtkWidget*         ttMainWindow,
-				   GdkEventKey*	      event,
-				   GtkListStore*      ttListStore);
-void       preferences_activated  (GSimpleAction     *action,
-				   GVariant	     *parameter,
-				   gpointer	      user_data);
-void       quit_activated         (GSimpleAction     *action,
-				   GVariant	     *parameter,
-				   gpointer	      user_data);
+#define TUTOTERM_TYPE (tutoterm_get_type ())
+G_DECLARE_FINAL_TYPE (Tutoterm, tutoterm, TUTOTERM, APP, GtkApplication)
 
-GtkWidget *ttExample, *ttLabelExample;
-//const char *accels[] = {"<Contol>Q", NULL};
+struct _Tutoterm
+{
+  GtkApplication parent;
+};
+
+// Members
+
+Tutoterm * tutoterm_new (void);
 
 #endif /* __TUTOTERM_H */
