@@ -1,6 +1,6 @@
 /* main.c -- main file of TutoTerm
  *
- * Copyright © 2017,2019 Félicien Pillot <felicien@gnu.org>
+ * Copyright © 2017,2019-2020 Félicien Pillot <felicien@gnu.org>
  * This file is part of TutoTerm.
  * 
  * TutoTerm is free software: you can redistribute it and/or modify
@@ -26,18 +26,24 @@
 int
 main (int argc, char **argv)
 {
+  Tutoterm *app;
+  int status;
+  
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (PACKAGE);
   
-  GtkApplication *app;
-  int status;
+  // Logging and debugging
+  g_log_set_handler (G_LOG_DOMAIN,
+		     G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL,
+		     g_log_default_handler,
+		     NULL);
   
-  app = gtk_application_new ("org.nongnu.tutoterm", G_APPLICATION_FLAGS_NONE);
-  g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
+  // Initialization and execution
+  app = tutoterm_new ();
   status = g_application_run (G_APPLICATION (app), argc, argv);
+  
   g_object_unref (app);
-
   return status;
 }
